@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -27,24 +27,24 @@
 EnvironmentSettingsRulesPage::EnvironmentSettingsRulesPage(QWidget *parent)
     : QWidget(parent)
 {
-    QVBoxLayout *mainLayout = new QVBoxLayout;
-    setLayout(mainLayout);
-    QLabel *lab = new QLabel(i18n("Rules:"));
+    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    QLabel *lab = new QLabel(i18n("Rules:"), this);
     lab->setObjectName(QStringLiteral("label"));
-    mPlainTextEdit = new EnvironmentPlainTextEdit;
-    mPlainTextEdit->setReadOnly(true);
-    mPlainTextEdit->setObjectName(QStringLiteral("plaintext"));
+    mRichTextEdit = new EnvironmentPlainTextEdit(this);
+    mRichTextEdit->setReadOnly(true);
+    mRichTextEdit->setObjectName(QStringLiteral("richtext"));
     mainLayout->addWidget(lab);
-    mainLayout->addWidget(mPlainTextEdit);
+    mainLayout->addWidget(mRichTextEdit);
 }
 
 EnvironmentSettingsRulesPage::~EnvironmentSettingsRulesPage()
 {
-
 }
 
 void EnvironmentSettingsRulesPage::setRules(const QString &rules)
 {
-    QString information = i18n("These rules cannot be edited with this application. You need to set them in QT_LOGGING_RULES variable directly.");
-    mPlainTextEdit->setPlainText(information + QLatin1Char('\n') + QLatin1Char('\n') + rules);
+    const QString information = QStringLiteral("<qt><b>") + i18n("These rules cannot be edited with this application. You need to set them in QT_LOGGING_RULES variable directly.") + QStringLiteral(
+        "</b><qt>");
+    QString newRules = rules;
+    mRichTextEdit->setHtml(information + i18n("Current rules:") + QStringLiteral("<br>") + newRules.replace(QLatin1String("\n"), QLatin1String("<br>")));
 }
